==> piwigo-2.7.4.zip: piwigo/language/sr_RS/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Инсталација';
$lang['Basic configuration'] = 'Основна подешења';
$lang['Default gallery language'] = 'Подразумевани језик галерије';
$lang['Database configuration'] = 'Подешавање базе';
$lang['Admin configuration'] = 'Администраторска подешења';
$lang['Start Install'] = 'Покрени инсталацију';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Биће приказано посетиоцима. Неопходно је за администрацију интернет страница';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Повезивање на сервер успешно, али повезивање на базу је немогућа';
$lang['Can\'t connect to server'] = 'Немогуће повезивање на сервер';
$lang['Host'] = 'Хост';
$lang['User'] = 'Корисник';
$lang['user login given by your host provider'] = 'корисничко име дато од стране Вашег давалаца интернет услуга';
$lang['user password given by your host provider'] = 'корисничка лозинка дата од стране Вашег давалаца интернет услуга';
$lang['Database name'] = 'Име базе';
$lang['also given by your host provider'] = 'такоде дато од Вашег дистрибутера интернет услуга';
$lang['Database table prefix'] = 'Префиx табела базе';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'име табеле базе биће префикс са њим (омогућава да управљате боље Вашим табелама)';
$lang['enter a login for webmaster'] = 'Унеси приступне податке за уредника интернет страница';
$lang['webmaster login can\'t contain characters \' or "'] = 'приступни подаци за уредника интернет страница не могу садржати знаке \' или "';
$lang['please enter your password again'] = 'молим унесите Вашу лозинку поново';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Сачувајте у тајности, омогућава приступ администраторском делу';
$lang['Password [confirm]'] = 'Лозинка[потврди]';
$lang['verification'] = 'Провера';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Потребна Вам је помоц? Питајте на  <a href="%s">Piwigo табли за поруке</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Посетиоци ће бити у могућности да са ове електронске адресе контактирају администратора странице';
$lang['PHP 5 is required'] = 'PHP 5 је неопходан';
$lang['It appears your webhost is currently running PHP %s.'] = 'Изгледа да Ваш сервер тренутно користи PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'ПиВиГо може покушати да промени Вашу конфигурацију на PHP 5 формирањем или мењањем .htaccess датотеке.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Имајте у виду да можете сами изменити Вашу конфигурацију рестартовати Piwigo после тога.';
$lang['Try to configure PHP 5'] = 'Покушајте да подестите PHP 5';
$lang['Sorry!'] = 'Жао нам је!';
$lang['Piwigo was not able to configure PHP 5.'] = 'ПиВиГо није успео да подеси PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Требало би да се обартите подршци Вашег хостинг провајдера за упутство како да промените на PHP 5 сами.';
$lang['Hope to see you back soon.'] = 'Надамо се да се ускоро поново видимо.';
$lang['Congratulations, Piwigo installation is completed'] = 'Честитамо, ПиВиГо инсталација је завршена';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Алтернативно решење је да копирате текст из кутије изнад и налепите у датотеку "local/config/database.inc.php" (Упозорење : database.inc.php мора садржати само текст из кутије, без линије или празних карактера)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Формирање конфигурационе датотеке local/config/database.inc.php неуспешно.';
$lang['Download the config file'] = 'Сними на рачунар конфигурациону датотеку';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Можете снимити на рачунар конфигурациону датотеку и послати је на local/config директоријум Ваше инсталације.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Не устручавајте се да посетите наш форум за помоћ: %s';
$lang['Just another Piwigo gallery'] = 'ПиВиГо фото галерија';
$lang['Welcome to my photo gallery'] = 'Добродошли у фото галерију';
$lang['Welcome to your new installation of Piwigo!'] = 'Добродошли у нову инсталацију ПиВиГо!';
$lang['localhost or other, supplied by your host provider'] = 'localhost или други назив који сте добили од провајдера';

==> piwigo-12.3.0.zip: piwigo/language/sr_RS/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Инсталација';
$lang['Basic configuration'] = 'Основна подешења';
$lang['Default gallery language'] = 'Подразумевани језик галерије';
$lang['Database configuration'] = 'Подешавање базе';
$lang['Admin configuration'] = 'Администраторска подешења';
$lang['Start Install'] = 'Покрени инсталацију';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Биће приказано посетиоцима. Неопходно је за администрацију интернет страница';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Повезивање на сервер успешно, али повезивање на базу је немогућа';
$lang['Can\'t connect to server'] = 'Немогуће повезивање на сервер';
$lang['Host'] = 'Хост';
$lang['User'] = 'Корисник';
$lang['user login given by your host provider'] = 'корисничко име дато од стране Вашег давалаца интернет услуга';
$lang['user password given by your host provider'] = 'корисничка лозинка дата од стране Вашег давалаца интернет услуга';
$lang['Database name'] = 'Име базе';
$lang['also given by your host provider'] = 'такоде дато од Вашег дистрибутера интернет услуга';
$lang['Database table prefix'] = 'Префиx табела базе';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'име табеле базе биће префикс са њим (омогућава да управљате боље Вашим табелама)';
$lang['enter a login for webmaster'] = 'Унеси приступне податке за уредника интернет страница';
$lang['webmaster login can\'t contain characters \' or "'] = 'приступни подаци за уредника интернет страница не могу садржати знаке \' или "';
$lang['please enter your password again'] = 'молим унесите Вашу лозинку поново';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Сачувајте у тајности, омогућава приступ администраторском делу';
$lang['Password [confirm]'] = 'Лозинка[потврди]';
$lang['verification'] = 'Провера';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Потребна Вам је помоц? Питајте на  <a href="%s">Piwigo табли за поруке</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Посетиоци ће бити у могућности да са ове електронске адресе контактирају администратора странице';
$lang['PHP 5 is required'] = 'PHP 5.2 је неопходан';
$lang['It appears your webhost is currently running PHP %s.'] = 'Изгледа да Ваш сервер тренутно користи PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'ПиВиГо може покушати да промени Вашу конфигурацију на PHP 5.2 формирањем или мењањем .htaccess датотеке.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Имајте у виду да можете сами изменити Вашу конфигурацију рестартовати Piwigo после тога.';
$lang['Try to configure PHP 5'] = 'Покушајте да подестите PHP 5.2';
$lang['Sorry!'] = 'Жао нам је!';
$lang['Piwigo was not able to configure PHP 5.'] = 'ПиВиГо није успео да подеси PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Требало би да се обартите подршци Вашег хостинг провајдера за упутство како да промените на PHP 5.2 сами.';
$lang['Hope to see you back soon.'] = 'Надамо се да се ускоро поново видимо.';
$lang['Congratulations, Piwigo installation is completed'] = 'Честитамо, ПиВиГо инсталација је завршена';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Алтернативно решење је да копирате текст из кутије изнад и налепите у датотеку "local/config/database.inc.php" (Упозорење : database.inc.php мора садржати само текст из кутије, без линије или празних карактера)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Формирање конфигурационе датотеке local/config/database.inc.php неуспешно.';
$lang['Download the config file'] = 'Сними на рачунар конфигурациону датотеку';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Можете снимити на рачунар конфигурациону датотеку и послати је на local/config директоријум Ваше инсталације.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Не устручавајте се да посетите наш форум за помоћ: %s';
$lang['Just another Piwigo gallery'] = 'ПиВиГо фото галерија';
$lang['Welcome to my photo gallery'] = 'Добродошли у фото галерију';
$lang['Welcome to your new installation of Piwigo!'] = 'Добродошли у нову инсталацију ПиВиГо!';
$lang['localhost or other, supplied by your host provider'] = 'localhost или други назив који сте добили од провајдера';
